==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/de.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Bitte sicherstellen, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Bitte sicherstellen, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Please provide a valid app key and secret." : "Bitte einen gültigen Anwendungsschlüssel mit Sicherheitsschlüssel eingeben.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storages" : "Externer Speicher",
    "Dropbox App Configuration" : "Dropbox-App Konfiguration",
    "Google Drive App Configuration" : "Google Drive - App Konfiguration",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Zugriff gestatten",
    "Error configuring OAuth1" : "Fehler beim Konfigurieren von OAuth1",
    "Error configuring OAuth2" : "Fehler beim Einrichten von OAuth2",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilität mit MAC NFD-Kodierung (langsam)",
    "Admin defined" : "Administrator festgelegt",
    "Saved" : "Gespeichert",
    "Saving..." : "Speichere…",
    "Save" : "Speichern",
    "Empty response from the server" : "Leere Antwort vom Server",
    "Couldn't access. Please logout and login to activate this mount point" : "Anmeldung nicht möglich. Bitte abmelden und erneut anmelden, damit von diesem Endpunkt zugegriffen werden kann.",
    "Couldn't get the information from the remote server: {code} {type}" : "Konnte die Information vom entfernten Server nicht abrufen: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Die Liste der externen Endpunkte konnte nicht empfangen werden: {type}",
    "There was an error with message: " : "Es ist ein Fehler mit folgender Meldung aufgetreten:",
    "External mount error" : "Fehler beim Einbinden des externen Speichers",
    "external-storage" : "Externer Speicher",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Es konnte keine Liste der Windows-Netzlaufwerke erstellt werden: leer Antwort vom Server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Einige der konfigurierten externen Bereitstellungspunkte  sind nicht angeschlossen. Bitte klicke auf die roten Zeile(n) für weitere Informationen",
    "Please enter the credentials for the {mount} mount" : "Bitte gib die Anmeldeinformationen für den {mount} externen Bereitstellungspunkt ein",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Credentials saved" : "Anmeldeinformationen gespeichert",
    "Credentials saving failed" : "Speichern der Anmeldeinformationen fehlgeschlagen",
    "Credentials required" : "Anmeldeinformationen benötigt",
    "Storage with ID \"%d\" not found" : "Der Speicher mit der ID „%d“ wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültiger Backend- oder Authentifizierungsmechanismus",
    "Invalid mount point" : "Ungültiger mount point",
    "Objectstore forbidden" : "Objekt nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Not permitted to use backend \"%s\"" : "Nicht zulässig Backend \"%s\" zu verwenden",
    "Not permitted to use authentication mechanism \"%s\"" : "verwende zulässigen Authentifizierungsmechanismus \"%s\" ",
    "Unsatisfied backend parameters" : "Unbefriedigende Backend- Parameter",
    "Unsatisfied authentication mechanism parameters" : "Unbefriedigende Authentifizierungsmechanismus Parameter",
    "Insufficient data: %s" : "Unzureichende Daten: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Speicher mit der ID \"%d\" kann nicht vom Benutzer bearbeitet werden",
    "Access key" : "Zugangsschlüssel",
    "Secret key" : "Geheimer Schlüssel",
    "Builtin" : "eingebaut",
    "None" : "Keine",
    "OAuth1" : "OAuth1",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Name des Mieters",
    "Identity endpoint URL" : "Identität Endpunkt-URL",
    "Rackspace" : "Rackspace",
    "API key" : "API-Schlüssel",
    "Global credentials" : "Globale Anmeldeinformationen",
    "Log-in credentials, save in database" : "Anmeldedaten in Datenbank speichern",
    "Username and password" : "Benutzername und Passwort",
    "Log-in credentials, save in session" : "Anmeldedaten in Sitzung speichern",
    "User entered, store in database" : "Benutzer eingetragen, in Datenbank gespeichert",
    "RSA public key" : "RSA öffentlicher Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfad-Stil aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicherer HTTPS://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicherer ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Lokal",
    "Location" : "Ort",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit dem Login über einen geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Service name" : "Service Name",
    "Request timeout (seconds)" : "Anfrage -Timeout ( Sekunden)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Die cURL-Unterstützung von PHP ist deaktiviert oder nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie Sich zur Installation an den Systemadministrator.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Die FTP-Unterstützung von PHP ist deaktiviert oder nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie Sich zur Installation an den Systemadministrator.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wenden Sie Sich zur Installation an den Systemadministrator.",
    "External storage support" : "Unterstützung für externen Speicher",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Externe Speicher können in den persönlichen Einstellungen hinzugefügt werden",
    "Name" : "Name",
    "Storage type" : "Speicher-Typ",
    "Scope" : "Anwendungsbereich",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Enable sharing" : "Freigaben einschalten",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "Folder name" : "Ordnername",
    "External storage" : "Externer Speicher",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount external storage" : "Benutzern erlauben, externen Speicher einzubinden",
    "Allow users to mount the following external storage" : "Benutzern erlauben, den oder die folgenden externen Speicher einzubinden:",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Storage with id \"%i\" is not user editable" : "Speicher mit der ID \"%i\" kann nicht vom Benutzer bearbeitet werden"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/de.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Externer Speicher",
    "Personal" : "Persönlich",
    "System" : "System",
    "Grant access" : "Zugriff gestatten",
    "Error configuring OAuth1" : "Fehler beim Konfigurieren von OAuth1",
    "Please provide a valid app key and secret." : "Bitte einen gültigen Anwendungsschlüssel mit Sicherheitsschlüssel eingeben.",
    "Error configuring OAuth2" : "Fehler beim Konfigurieren von OAuth2",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilität mit MAC NFD-Kodierung (langsam)",
    "Admin defined" : "Administrator festgelegt",
    "Saved" : "Gespeichert",
    "Saving..." : "Speichere…",
    "Save" : "Speichern",
    "Empty response from the server" : "Leere Antwort vom Server",
    "Couldn't access. Please log out and in again to activate this mount point" : "Zugriff nicht möglich. Bitte abmelden und erneut anmelden, um diesen Endpunkt zu aktivieren.",
    "Couldn't get the information from the remote server: {code} {type}" : "Konnte die Information vom entfernten Server nicht abrufen: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Die Liste der externen Endpunkte konnte nicht empfangen werden: {type}",
    "There was an error with message: " : "Es ist ein Fehler mit folgender Meldung aufgetreten:",
    "External mount error" : "Fehler beim Einbinden des externen Speichers",
    "external-storage" : "Externer Speicher",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Es konnte keine Liste der Windows-Netzlaufwerke empfangen werden: Leere Antwort vom Server",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Einige der konfigurierten externen Bereitstellungspunkte  sind nicht angeschlossen. Bitte klicke auf die roten Zeile(n) für weitere Informationen",
    "Please enter the credentials for the {mount} mount" : "Bitte gib die Anmeldeinformationen für den {mount} externen Bereitstellungspunkt ein",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Credentials saved" : "Anmeldeinformationen gespeichert",
    "Credentials saving failed" : "Speichern der Anmeldeinformationen fehlgeschlagen",
    "Credentials required" : "Anmeldeinformationen benötigt",
    "Storage with ID \"%d\" not found" : "Der Speicher mit der ID „%d“ wurde nicht gefunden",
    "Invalid backend or authentication mechanism class" : "Ungültiger Backend- oder Authentifizierungsmechanismus",
    "Invalid mount point" : "Ungültiger mount point",
    "Objectstore forbidden" : "Objekt nicht erlaubt",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Not permitted to use backend \"%s\"" : "Nicht zulässig Backend \"%s\" zu verwenden",
    "Not permitted to use authentication mechanism \"%s\"" : "verwende zulässigen Authentifizierungsmechanismus \"%s\" ",
    "Unsatisfied backend parameters" : "Unbefriedigende Backend- Parameter",
    "Unsatisfied authentication mechanism parameters" : "Unbefriedigende Authentifizierungsmechanismus Parameter",
    "Insufficient data: %s" : "Unzureichende Daten: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Speicher mit der ID \"%d\" kann nicht vom Benutzer bearbeitet werden",
    "Access key" : "Zugangsschlüssel",
    "Secret key" : "Geheimer Schlüssel",
    "Builtin" : "eingebaut",
    "None" : "Keine",
    "OAuth1" : "OAuth1",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Name des Mieters",
    "Identity endpoint URL" : "Identität Endpunkt-URL",
    "Rackspace" : "Rackspace",
    "API key" : "API-Schlüssel",
    "Global credentials" : "Globale Anmeldeinformationen",
    "Log-in credentials, save in database" : "Anmeldedaten in Datenbank speichern",
    "Username and password" : "Benutzername und Passwort",
    "Log-in credentials, save in session" : "Anmeldedaten in Sitzung speichern",
    "User entered, store in database" : "Benutzer eingetragen, in Datenbank gespeichert",
    "RSA public key" : "RSA öffentlicher Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfad-Stil aktivieren",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure https://" : "Sicherer HTTPS://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Sicherer ftps://",
    "Local" : "Lokal",
    "Location" : "Ort",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP mit der Anmeldung über einen geheimen Schlüssel",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Share",
    "Domain" : "Domain",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Anmeldung",
    "Username as share" : "Benutzername als Freigabe",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Service name" : "Service Name",
    "Request timeout (seconds)" : "Anfrage -Timeout ( Sekunden)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Die cURL-Unterstützung von PHP ist deaktiviert oder nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an den Systemadministrator.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Die FTP-Unterstützung von PHP ist deaktiviert oder nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an den Systemadministrator.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "\"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an den Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Externe Speicher können in den persönlichen Einstellungen hinzugefügt werden",
    "Name" : "Name",
    "Storage type" : "Speicher-Typ",
    "Scope" : "Anwendungsbereich",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Enable sharing" : "Freigaben einschalten",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "Folder name" : "Ordnername",
    "External storage" : "Externer Speicher",
    "Authentication" : "Authentifizierung",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Allow users to mount external storage" : "Benutzern erlauben, externen Speicher einzubinden",
    "Allow users to mount the following external storage" : "Benutzern erlauben, den oder die folgenden externen Speicher einzubinden:",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Bitte sicherstellen, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Bitte sicherstellen, dass der Anwendungsschlüssel und Sicherheitsschlüssel korrekt sind.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "Dropbox App Configuration" : "Dropbox-App Konfiguration",
    "Google Drive App Configuration" : "Google Drive - App Konfiguration",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Storage with id \"%i\" is not user editable" : "Speicher mit der ID \"%i\" kann nicht vom Benutzer bearbeitet werden",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=2; plural=(n != 1);");
